This crate provides functionality for parsing markdown style headers.
Structs
- Parser
- A stateful line parser that tracks the current path of headers.
- Path
Changes - Represents the changes to be made to a path.
- Subheader
Without Header - Indicates that a subheader was found without a corresponding header.
Enums
Functions
- parse_
header - Parses a header from a line of text.