pub enum Line<'a> {
Header {
level: usize,
},
Content(&'a str),
}Expand description
The classification of a single line by a Parser.
Variants
Header
The line was a header at the given level (0 for #).
The current path of headers is available through Parser::path.
Content(&'a str)
The line was not a header. It is passed through unchanged.