Line

Enum Line 

pub enum Line<'a> {
    Header {
        level: usize,
    },
    Content(&'a str),
}
The classification of a single line by a Parser.

Variants



Header

The line was a header at the given level (0 for #).

The current path of headers is available through Parser::path.

Fields

level: usize

The nesting level of the header, starting at 0.



Content(&'a str)

The line was not a header. It is passed through unchanged.